@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "move-mode" "1.1.2"
+(define-package "move-mode" "20251224.1152"
   "A major-mode for editing Move language."
   '((emacs "25.1"))
   :url "https://github.com/amnn/move-mode"
